#####################
### Preliminaries ###
#####################
# Installing required packages 
install.packages("spdep")
install.packages("shapefiles") 
install.packages("CARBayes") 
install.packages("rgdal")  

# Loading required packages into the library
require(spdep)
require(shapefiles)
require(CARBayes)
require(rgdal)

###############################
### Creating a Scotland map ###
###############################
# Read population data for Scotland 
pop_Scotland_C <- read.csv('Scotland_County.csv', row.names = 1)

# Reading in border
shp_Scotland_C <- read.shp(shp.name = "Scotland_County.shp")

# Reading 
dbf_Scotland_C <- read.dbf(dbf.name = "Scotland_County.dbf")

# Printing first six rows
head(pop_Scotland_C)

# Combining population data and the shapefile
Scotland_C <- combine.data.shapefile(data = pop_Scotland_C, # Dataset to attach
                                     shp  = shp_Scotland_C, # Shapefile
                                     dbf  = dbf_Scotland_C) # Database file

# Creating Map of population counts 
spplot(obj  = Scotland_C, # Spatial object to be plotted
       zcol = c("Pop2010"), # Choice of the column  the object you are plotting. 
       main = "Population Counts", # Plot title
       at   = seq(100000,2000000, length.out=20), # Break points for legend
       col.regions = hsv(0.6, seq(0.2, 1, length.out=20), 1)) # Create a set of colours

########################################################
### COPD in England - Reading in data and shapefiles ###
########################################################
# Reading in borders
shp <- read.shp(shp.name="englandlocalauthority.shp")
dbf <- read.dbf(dbf.name="englandlocalauthority.dbf")

# Reading in observed numbers of hospital admissions in England by local authority
observed <- read.csv(file="copdmortalityobserved.csv", row.names=1)

# Reading in expected numbers of hospital admissions in England by local authority
expected <- read.csv(file="copdmortalityexpected.csv", row.names=1)

# Printing first six rows of the observed counts 
head(observed)

# Printing first six rows of the expected counts 
head(expected)

# Summarising the observed counts 
summary(observed)

# Summarising the expected counts 
summary(expected)

################################################
### COPD in England - Modelling the raw SMRs ###
################################################
# Calculating the raw SMRs
SMR_raw <- observed[ ,-1]/expected

# Altering column names
names(SMR_raw) <- c("SMR2001", "SMR2002", "SMR2003", "SMR2004", "SMR2005", 
                    "SMR2006", "SMR2007", "SMR2008", "SMR2009", "SMR2010")

# Printing first six rows of raw SMRs
head(SMR_raw)

# Summarising raw SMRs
summary(SMR_raw)

##############################################
### COPD in England - Mapping the raw SMRs ###
##############################################
# Combining Raw SMRs and the shapefile
SMRspatial_raw <- combine.data.shapefile(data = SMR_raw, # Dataset to attach
                                         shp  = shp,     # Shapefile
                                         dbf  = dbf)     # Database file

# Creating breaks for legend in plot
range <- seq(min(SMR_raw$SMR2010)-0.01, max(SMR_raw$SMR2010)+0.01, length.out=11)

# Creating map of Raw SMRs in England in 2010
spplot(obj  = SMRspatial_raw,    # Spatial object to be plotted
       zcol = c("SMR2010"),  # Choice of the column  the object you are plotting. 
       at   = range,         # Break points for colours
       col  = "transparent", # Choice of colour
       col.regions = hsv(0.6, seq(0.2, 1, length.out=10), 1)) # Create a set of colours

#####################################################
### COPD in England - Modelling the smoothed SMRs ###
#####################################################
# Creates the neighbourhood
W.nb <- poly2nb(SMRspatial_raw, row.names = rownames(SMRspatial_raw)) 

# Creates a matrix for following function call
W.mat <- nb2mat(W.nb, style="B") 

# Running smoothing model
model <- S.CARleroux(formula=observed$Y2010~offset(log(expected$E2010)), # Model Formula
                     family="poisson",                      # Choosing Poisson Regression
                     W=W.mat,                               # Neighbourhood matrix 
                     burnin=20000,                          # Number of burn in samples
                     n.sample=100000,                       # Number of MCMC samples
                     thin=10, 
                     fix.rho=TRUE, 
                     rho=1)

# Creating a dataset with smoothed SMRs in 2010
SMR2010 <- model$fitted.values / expected$E2010 
SMR_smooth <- as.data.frame(SMR2010, row.names = rownames(observed))

# Printing first six rows of smoothed SMRs
head(SMR_smooth)

# Summarising smoothed SMRs
summary(SMR_smooth)

###################################################
### COPD in England - Mapping the smoothed SMRs ###
###################################################
# Combining smoothed SMRs and the shapefile
SMRspatial_smooth <- combine.data.shapefile(data = SMR_smooth, # Dataset to attach
                                            shp  = shp,        # Shapefile
                                            dbf  = dbf)        # Database file

# Creating map of Raw SMRs in England in 2010
spplot(obj  = SMRspatial_smooth,    # Spatial object to be plotted
       zcol = c("SMR2010"),         # Choice of the column  the object you are plotting. 
       at   = range,                # Break points for colours
       col  = "transparent",        # Choice of colour
       col.regions = hsv(0.6, seq(0.2, 1, length.out=10), 1)) # Create a set of colours

